## 👩‍🔬 Use Cases <!-- {docsify-ignore} -->
Here you can find real use cases of the library, with some explanations of the situation or use case, and how I used **bvhTools** to solve the problem.
### Use Case 1 (Centering an entire dataset)
